Documentation
¶
Index ¶
- type Logger
- type Option
- type Projector
- func (p *Projector) GetActiveSignal(ctx context.Context, port string) (bool, error)
- func (p *Projector) GetBlanked(ctx context.Context) (bool, error)
- func (p *Projector) GetInfo(ctx context.Context) (interface{}, error)
- func (p *Projector) GetInput(ctx context.Context) (string, error)
- func (p *Projector) GetMutedByBlock(ctx context.Context, block string) (bool, error)
- func (p *Projector) GetPower(ctx context.Context) (string, error)
- func (p *Projector) GetVolumeByBlock(ctx context.Context, block string) (int, error)
- func (p *Projector) SetBlanked(ctx context.Context, blanked bool) error
- func (p *Projector) SetInput(ctx context.Context, input string) error
- func (p *Projector) SetMutedByBlock(ctx context.Context, block string, muted bool) error
- func (p *Projector) SetPower(ctx context.Context, power string) error
- func (p *Projector) SetVolumeByBlock(ctx context.Context, block string, volume int) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶ added in v0.1.0
type Logger interface {
Debugf(format string, a ...interface{})
Infof(format string, a ...interface{})
Warnf(format string, a ...interface{})
Errorf(format string, a ...interface{})
}
Logger is a logger usable by Projector.
type Option ¶
type Option interface {
// contains filtered or unexported methods
}
Option configures how to create the Projector.
func WithDelay ¶
WithDelay changes the delay between sending commands to the Projector. The default value is 250 milliseconds. See more details about delay in https://github.com/byuoitav/connpool.
func WithLogger ¶ added in v0.1.0
WithLogger adds a logger to Projector. Projector will log appropriate information about the underlying connection and the commands being sent. The default value is nil, meaning that no logs are written.
type Projector ¶
type Projector struct {
// contains filtered or unexported fields
}
func NewProjector ¶
func (*Projector) GetActiveSignal ¶ added in v0.0.2
func (*Projector) GetMutedByBlock ¶
func (*Projector) GetVolumeByBlock ¶
func (*Projector) SetBlanked ¶
func (*Projector) SetMutedByBlock ¶
Click to show internal directories.
Click to hide internal directories.